@@ -1,17 +1,17 @@
-/* 
+/*
  * This file is part of the Nepomuk KDE project.
- * Copyright (C) 2006-2008 Sebastian Trueg <trueg@kde.org>
+ * Copyright (C) 2006-2009 Sebastian Trueg <trueg@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
@@ -28,6 +28,10 @@
 #include <QtCore/QUrl>
 #include <QtCore/QVariant>
 
+namespace Soprano {
+    class Node;
+}
+
 namespace Nepomuk {
 
     class Resource;
@@ -35,8 +39,8 @@ namespace Nepomuk {
     /**
      * \class Variant variant.h Nepomuk/Variant
      *
-     * The %Nepomuk Variant extends over QVariant by introducing
-     * direct support for Resource embedding, automatic list conversion 
+     * \brief The %Nepomuk Variant extends over QVariant by introducing
+     * direct support for Resource embedding, automatic list conversion
      * and a restricted set of supported types.
      *
      * Important differences are:
@@ -47,8 +51,14 @@ namespace Nepomuk {
      *     method.
      * \li toString and toStringList always return a valid list and do automatic
      *     conversion from the actual type used in the Variant. Thus, if one only
-     *     needs to display the value in a Variant toString and toStringList 
+     *     needs to display the value in a Variant toString and toStringList
      *     do the job.
+     * \li Variant comes with direct support for Resource. There is one special
+     *     thing about QUrl Variants though: for both isUrl() and
+     *     isResource() return \p true. However, toUrl() will return different
+     *     values for Resource and for QUrl Variants: in the former case the
+     *     actual Resource::resourceUri() is returned which can be different
+     *     in case of file:/ URLs.
      *
      * \author Sebastian Trueg <trueg@kde.org>
      */
@@ -160,7 +170,7 @@ namespace Nepomuk {
         bool operator!=( const Variant& other ) const;
 
         bool isValid() const;
-                
+
         /**
          * \return the QT Meta type id of the type
          */
@@ -215,27 +225,99 @@ namespace Nepomuk {
 
         QVariant variant() const;
 
+        /**
+         * Convert into an int value. Returns a valid value for
+         * all decimal types.
+         *
+         * Will return the first value of an int list.
+         */
         int toInt() const;
+
+        /**
+         * Convert into a qlonglong value. Returns a valid value for
+         * all decimal types.
+         *
+         * Will return the first value of a qlonglong list.
+         */
         qlonglong toInt64() const;
+
+        /**
+         * Convert into a uint value. Returns a valid value for
+         * all decimal types.
+         *
+         * Will return the first value of a uint list.
+         */
         uint toUnsignedInt() const;
+
+        /**
+         * Convert into a qulonglong value. Returns a valid value for
+         * all decimal types.
+         *
+         * Will return the first value of a qulonglong list.
+         */
         qulonglong toUnsignedInt64() const;
 
+        /**
+         * Convert into a bool value.
+         *
+         * Will return the first value of a bool list.
+         */
         bool toBool() const;
+
+        /**
+         * Convert into a double value.
+         *
+         * Will return the first value of a double list.
+         */
         double toDouble() const;
 
         /**
          * The toString() method is a little more powerful than other
          * toXXX methods since it actually converts all values to string.
-         * Thus, toString should work always (even list variants are converted 
+         * Thus, toString should work always (even list variants are converted
          * to a comma-separated list)
          *
          * Resources are converted to a string representation of their URI.
          */
         QString toString() const;
+
+        /**
+         * Convert into a QDate value.
+         *
+         * Will return the first value of a QDate list.
+         */
         QDate toDate() const;
+
+        /**
+         * Convert into a QTime value.
+         *
+         * Will return the first value of a QTime list.
+         */
         QTime toTime() const;
+
+        /**
+         * Convert into a QDateTime value.
+         *
+         * Will return the first value of a QDateTime list.
+         */
         QDateTime toDateTime() const;
+
+        /**
+         * Convert into a QUrl value. Can handle both QUrl and Resource variants.
+         * The latter will be converted into its resource URI
+         *
+         * Will return the first value of a QUrl list.
+         *
+         * \sa Resource::resourceUri
+         */
         QUrl toUrl() const;
+
+        /**
+         * Convert into a Resource value.
+         *
+         * Will return the first value of a Resource list. Will also convert QUrl
+         * variants.
+         */
         Resource toResource() const;
 
         QList<int> toIntList() const;
@@ -263,6 +345,20 @@ namespace Nepomuk {
          */
         QList<Variant> toVariantList() const;
 
+        /**
+         * Convert a Variant to a Node.
+         *
+         * \since 4.6
+         */
+        Soprano::Node toNode() const;
+
+        /**
+         * Convert a Variant to a a list of Nodes.
+         *
+         * \since 4.6
+         */
+        QList<Soprano::Node> toNodeList() const;
+        
         /**
          * Create a Variant object by parsing string \a value based on \a type.
          * If \a type is unknown a simple string Variant object is returned
@@ -270,6 +366,20 @@ namespace Nepomuk {
          */
         static Variant fromString( const QString& value, int type );
 
+        /**
+         * Create a Variant object from a Soprano::Node.
+         *
+         * \since 4.5
+         */
+        static Variant fromNode( const Soprano::Node& node );
+
+        /**
+         * Create a Variant object from a list of Soprano::Node.
+         *
+         * \since 4.6
+         */
+        static Variant fromNodeList( const QList<Soprano::Node>& node );
+
     private:
         class Private;
         Private* const d;
